(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';

import { getConceptById } from './globalTreeStoreHelper';
import Openable from './Openable';
import CategoryTree from './CategoryTree';
import CategoryTreeNodeTextContainer from './CategoryTreeNodeTextContainer';
import './reducer';

var sumMatchingEntries = function sumMatchingEntries(children, initSum) {
  return children.reduce(function (sum, treeId) {
    var rootConcept = getConceptById(treeId);
    var rootMatchingEntries = rootConcept ? rootConcept.matchingEntries : 0;

    return rootMatchingEntries ? sum + rootMatchingEntries : sum;
  }, initSum);
};

var CategoryTreeFolder = function CategoryTreeFolder(props) {
  var tree = props.tree,
      search = props.search;

  var matchingEntries = !tree.children || !tree.matchingEntries ? null : sumMatchingEntries(tree.children, tree.matchingEntries);

  return React.createElement(
    'div',
    { className: 'category-tree-folder category-tree-node' },
    React.createElement(CategoryTreeNodeTextContainer, {
      node: {
        id: props.treeId,
        label: props.tree.label,
        description: props.tree.description,
        matchingEntries: matchingEntries,
        dateRange: props.tree.dateRange,
        additionalInfos: props.tree.additionalInfos,
        hasChildren: !!props.tree.children && props.tree.children.length > 0
      },
      createQueryElement: function createQueryElement() {
        // We don't have to implement this since CategoryTreeFolders should never be
        // dragged into the editor, hence they're 'active: false' and thus not draggable
      },
      open: props.open || false,
      depth: props.depth,
      active: props.active,
      onTextClick: props.onToggleOpen
    }),
    props.open && props.tree.children && props.tree.children.map(function (childId, i) {
      var tree = props.trees[childId];

      if (tree.detailsAvailable) {
        var rootConcept = getConceptById(childId);

        return React.createElement(CategoryTree, {
          key: i,
          id: childId,
          label: tree.label,
          tree: rootConcept,
          treeId: childId,
          loading: tree.loading,
          error: tree.error,
          depth: props.depth + 1,
          search: search
        });
      } else {
        return tree.children && props.tree.children && props.tree.children.length > 0 ? React.createElement(OpenableCategoryTreeFolder, {
          key: i,
          trees: props.trees,
          tree: tree,
          treeId: childId,
          openInitially: false,
          depth: props.depth + 1,
          active: tree.active
        }) : React.createElement(CategoryTreeFolder, {
          key: i,
          trees: props.trees,
          tree: tree,
          treeId: childId,
          openInitially: false,
          depth: props.depth + 1,
          active: tree.active
        });
      }
    })
  );
};

var OpenableCategoryTreeFolder = Openable(CategoryTreeFolder);

var _default = OpenableCategoryTreeFolder;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(sumMatchingEntries, 'sumMatchingEntries', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeFolder.js');
  reactHotLoader.register(CategoryTreeFolder, 'CategoryTreeFolder', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeFolder.js');
  reactHotLoader.register(OpenableCategoryTreeFolder, 'OpenableCategoryTreeFolder', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeFolder.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeFolder.js');
  leaveModule(module);
})();

;