(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import { DragSource } from 'react-dnd';
import Highlighter from 'react-highlight-words';
import classnames from 'classnames';

import { AdditionalInfoHoverable } from '../tooltip';
import { isEmpty } from '../common/helpers';
import { dndTypes } from '../common/constants';

import '../tooltip/AdditionalInfoHoverable';
import '../standard-query-editor/types';
import './reducer';

var CategoryTreeNodeTextContainer = function CategoryTreeNodeTextContainer(props) {
  var zeroEntries = !isEmpty(props.node.matchingEntries) && props.node.matchingEntries === 0;
  var searching = props.search && props.search.searching;
  var description = ' - ' + props.node.description;

  var render = React.createElement(
    'div',
    {
      className: 'category-tree-node__text-container',
      onClick: props.onTextClick,
      style: { paddingLeft: props.depth * 20 }
    },
    React.createElement(
      'p',
      {
        className: classnames("category-tree-node__text", {
          "category-tree-node__text--open": !!props.open,
          "category-tree-node__text--zero": zeroEntries
        })
      },
      props.node.hasChildren && React.createElement('i', { className: classnames('category-tree-node__icon', 'fa', {
          'fa-folder-open': !!props.open || searching,
          'fa-folder': !props.open && !searching
        }) }),
      React.createElement(
        'span',
        null,
        searching ? React.createElement(Highlighter, {
          searchWords: props.search && props.search.words,
          autoEscape: true,
          textToHighlight: props.node.label
        }) : props.node.label
      ),
      searching && props.node.description ? React.createElement(Highlighter, {
        searchWords: props.search && props.search.words,
        autoEscape: true,
        textToHighlight: description
      }) : props.node.description && description
    )
  );

  // Don't allow dragging with inactive elements
  return props.active === false ? render : props.connectDragSource(render);
};

/**
 * Implements the drag source contract.
 */
var nodeSource = {
  beginDrag: function beginDrag(props) {
    // Return the data describing the dragged item
    return props.createQueryElement();
  }
};

/**
 * Specifies the props to inject into your component.
 */
var collect = function collect(connect, monitor) {
  return {
    connectDragSource: connect.dragSource(),
    isDragging: monitor.isDragging()
  };
};

var DraggableCategoryTreeNodeTextContainer = DragSource(dndTypes.CATEGORY_TREE_NODE, nodeSource, collect)(CategoryTreeNodeTextContainer);

var _default = AdditionalInfoHoverable(DraggableCategoryTreeNodeTextContainer);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(CategoryTreeNodeTextContainer, 'CategoryTreeNodeTextContainer', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeNodeTextContainer.js');
  reactHotLoader.register(nodeSource, 'nodeSource', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeNodeTextContainer.js');
  reactHotLoader.register(collect, 'collect', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeNodeTextContainer.js');
  reactHotLoader.register(DraggableCategoryTreeNodeTextContainer, 'DraggableCategoryTreeNodeTextContainer', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeNodeTextContainer.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/CategoryTreeNodeTextContainer.js');
  leaveModule(module);
})();

;