var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { includes } from '../common/helpers';


// Globally store the huge (1-5 MB) trees for read only
// - keeps the redux store free from huge data
window.categoryTrees = {};

// To make this global variable a little more sane to use,
// we only use it with the following  getters / setters


//
// RESETTER
//
export function resetAllTrees() {
  window.categoryTrees = {};
};

//
// SETTER
//
export function setTree(rootConcept, treeId, tree) {
  // This replaces the root concept with the one loaded initially (at /concepts)
  var concepts = _extends({}, tree, _defineProperty({}, treeId, rootConcept));

  window.categoryTrees[treeId] = concepts;
};

//
// GETTER
//
export function getConceptById(conceptId) {
  var keys = Object.keys(window.categoryTrees);

  for (var i = 0; i < keys.length; i++) {
    var concept = window.categoryTrees[keys[i]][conceptId];

    if (concept) return concept;
  }

  return null;
}

//
// GETTER including parent tables all the way to the root concept
//
var findParentConcepts = function findParentConcepts(concepts) {
  // Get parent from first concept
  var parentId = concepts[0].parent;
  var parentConcept = getConceptById(parentId);

  if (!parentConcept) return concepts;

  var parentConceptWithId = _extends({}, parentConcept, {
    id: parentId
  });

  // Will return a list like
  // [rootConcept, childConcept, grandChildConcept, grandGrandChildConcept, ...]
  return findParentConcepts([parentConceptWithId].concat(_toConsumableArray(concepts)));
};

export var getConceptsByIdsWithTables = function getConceptsByIdsWithTables(conceptIds, rootConcepts) {
  var concepts = conceptIds.map(function (c) {
    var concept = getConceptById(c);

    return concept !== null ? _extends({}, concept, { id: c }) : null;
  }).filter(function (c) {
    return !!c;
  });

  if (concepts.length !== conceptIds.length) return null;

  var parentConceptIds = findParentConcepts(concepts).map(function (c) {
    return c.id.toString();
  } // toString so we can find them by object keys
  );

  var parentConceptsWithTables = Object.keys(rootConcepts).filter(function (id) {
    return includes(parentConceptIds, id) && !!rootConcepts[id].tables;
  }).map(function (id) {
    return { id: id, concept: rootConcepts[id] };
  });

  // There should only be one exact root node that has table information
  // If it's more or less than one, something went wrong
  if (parentConceptsWithTables.length !== 1) return null;

  return {
    concepts: concepts,
    root: parentConceptsWithTables[0].id,
    tables: parentConceptsWithTables[0].concept.tables
  };
};

export var hasConceptChildren = function hasConceptChildren(node) {
  if (!node) return false;

  var concept = getConceptById(node.ids);

  return concept && concept.children && concept.children.length > 0;
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(resetAllTrees, 'resetAllTrees', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/globalTreeStoreHelper.js');
  reactHotLoader.register(setTree, 'setTree', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/globalTreeStoreHelper.js');
  reactHotLoader.register(getConceptById, 'getConceptById', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/globalTreeStoreHelper.js');
  reactHotLoader.register(findParentConcepts, 'findParentConcepts', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/globalTreeStoreHelper.js');
  reactHotLoader.register(getConceptsByIdsWithTables, 'getConceptsByIdsWithTables', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/globalTreeStoreHelper.js');
  reactHotLoader.register(hasConceptChildren, 'hasConceptChildren', '/home/travis/build/bakdata/conquery/frontend/lib/js/category-trees/globalTreeStoreHelper.js');
  leaveModule(module);
})();

;