(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import T from 'i18n-react';
import api from '../../api';

import { defaultSuccess, defaultError } from '../../common/actions';

import { LOAD_PREVIOUS_QUERIES_START, LOAD_PREVIOUS_QUERIES_SUCCESS, LOAD_PREVIOUS_QUERIES_ERROR, LOAD_PREVIOUS_QUERY_START, LOAD_PREVIOUS_QUERY_SUCCESS, LOAD_PREVIOUS_QUERY_ERROR, RENAME_PREVIOUS_QUERY_START, RENAME_PREVIOUS_QUERY_SUCCESS, RENAME_PREVIOUS_QUERY_ERROR, TOGGLE_EDIT_PREVIOUS_QUERY_LABEL, TOGGLE_EDIT_PREVIOUS_QUERY_TAGS, RETAG_PREVIOUS_QUERY_START, RETAG_PREVIOUS_QUERY_SUCCESS, RETAG_PREVIOUS_QUERY_ERROR, TOGGLE_SHARE_PREVIOUS_QUERY_START, TOGGLE_SHARE_PREVIOUS_QUERY_SUCCESS, TOGGLE_SHARE_PREVIOUS_QUERY_ERROR, DELETE_PREVIOUS_QUERY_START, DELETE_PREVIOUS_QUERY_SUCCESS, DELETE_PREVIOUS_QUERY_ERROR } from './actionTypes';

export var loadPreviousQueriesStart = function loadPreviousQueriesStart() {
  return { type: LOAD_PREVIOUS_QUERIES_START };
};
export var loadPreviousQueriesSuccess = function loadPreviousQueriesSuccess(res) {
  return defaultSuccess(LOAD_PREVIOUS_QUERIES_SUCCESS, res);
};
export var loadPreviousQueriesError = function loadPreviousQueriesError(err) {
  return defaultError(LOAD_PREVIOUS_QUERIES_ERROR, err);
};

export var loadPreviousQueries = function loadPreviousQueries(datasetId) {
  return function (dispatch) {
    dispatch(loadPreviousQueriesStart());

    return api.getStoredQueries(datasetId).then(function (r) {
      return dispatch(loadPreviousQueriesSuccess(r));
    }, function (e) {
      return dispatch(loadPreviousQueriesError(e));
    });
  };
};

export var loadPreviousQueryStart = function loadPreviousQueryStart(queryId) {
  return { type: LOAD_PREVIOUS_QUERY_START, payload: { queryId: queryId } };
};
export var loadPreviousQuerySuccess = function loadPreviousQuerySuccess(queryId, res) {
  return defaultSuccess(LOAD_PREVIOUS_QUERY_SUCCESS, res, { queryId: queryId });
};
export var loadPreviousQueryError = function loadPreviousQueryError(queryId, err) {
  return defaultError(LOAD_PREVIOUS_QUERY_ERROR, err, { queryId: queryId });
};

export var loadPreviousQuery = function loadPreviousQuery(datasetId, queryId) {
  return function (dispatch) {
    dispatch(loadPreviousQueryStart(queryId));

    return api.getStoredQuery(datasetId, queryId).then(function (r) {
      return dispatch(loadPreviousQuerySuccess(queryId, r));
    }, function (e) {
      return dispatch(loadPreviousQueryError(queryId, {
        message: T.translate('previousQuery.loadError')
      }));
    });
  };
};

export var loadAllPreviousQueriesInGroups = function loadAllPreviousQueriesInGroups(groups, datasetId) {
  return groups.reduce(function (actions, group) {
    return [].concat(_toConsumableArray(actions), _toConsumableArray(group.elements.filter(function (element) {
      return element.type === 'QUERY';
    }).map(function (element) {
      return loadPreviousQuery(datasetId, element.id);
    })));
  }, []);
};

export var toggleEditPreviousQueryLabel = function toggleEditPreviousQueryLabel(queryId) {
  return {
    type: TOGGLE_EDIT_PREVIOUS_QUERY_LABEL,
    payload: { queryId: queryId }
  };
};

export var renamePreviousQueryStart = function renamePreviousQueryStart(queryId) {
  return { type: RENAME_PREVIOUS_QUERY_START, payload: { queryId: queryId } };
};
export var renamePreviousQuerySuccess = function renamePreviousQuerySuccess(queryId, label, res) {
  return defaultSuccess(RENAME_PREVIOUS_QUERY_SUCCESS, res, { queryId: queryId, label: label });
};
export var renamePreviousQueryError = function renamePreviousQueryError(queryId, err) {
  return defaultError(RENAME_PREVIOUS_QUERY_ERROR, err, { queryId: queryId });
};

export var renamePreviousQuery = function renamePreviousQuery(datasetId, queryId, label) {
  return function (dispatch) {
    dispatch(renamePreviousQueryStart(queryId));

    return api.patchStoredQuery(datasetId, queryId, { label: label }).then(function (r) {
      dispatch(renamePreviousQuerySuccess(queryId, label, r));
      dispatch(toggleEditPreviousQueryLabel(queryId));
    }, function (e) {
      return dispatch(renamePreviousQueryError(queryId, {
        message: T.translate('previousQuery.renameError')
      }));
    });
  };
};

export var toggleEditPreviousQueryTags = function toggleEditPreviousQueryTags(queryId) {
  return {
    type: TOGGLE_EDIT_PREVIOUS_QUERY_TAGS,
    payload: { queryId: queryId }
  };
};

export var retagPreviousQueryStart = function retagPreviousQueryStart(queryId) {
  return { type: RETAG_PREVIOUS_QUERY_START, payload: { queryId: queryId } };
};
export var retagPreviousQuerySuccess = function retagPreviousQuerySuccess(queryId, tags, res) {
  return defaultSuccess(RETAG_PREVIOUS_QUERY_SUCCESS, res, { queryId: queryId, tags: tags });
};
export var retagPreviousQueryError = function retagPreviousQueryError(queryId, err) {
  return defaultError(RETAG_PREVIOUS_QUERY_ERROR, err, { queryId: queryId });
};

export var retagPreviousQuery = function retagPreviousQuery(datasetId, queryId, tags) {
  return function (dispatch) {
    dispatch(retagPreviousQueryStart(queryId));

    return api.patchStoredQuery(datasetId, queryId, { tags: tags }).then(function (r) {
      dispatch(retagPreviousQuerySuccess(queryId, tags, r));
      dispatch(toggleEditPreviousQueryTags(queryId));
    }, function (e) {
      return dispatch(retagPreviousQueryError(queryId, {
        message: T.translate('previousQuery.retagError')
      }));
    });
  };
};

export var toggleSharePreviousQueryStart = function toggleSharePreviousQueryStart(queryId) {
  return { type: TOGGLE_SHARE_PREVIOUS_QUERY_START, payload: { queryId: queryId } };
};
export var toggleSharePreviousQuerySuccess = function toggleSharePreviousQuerySuccess(queryId, shared, res) {
  return defaultSuccess(TOGGLE_SHARE_PREVIOUS_QUERY_SUCCESS, res, { queryId: queryId, shared: shared });
};
export var toggleSharePreviousQueryError = function toggleSharePreviousQueryError(queryId, err) {
  return defaultError(TOGGLE_SHARE_PREVIOUS_QUERY_ERROR, err, { queryId: queryId });
};

export var toggleSharePreviousQuery = function toggleSharePreviousQuery(datasetId, queryId, shared) {
  return function (dispatch) {
    dispatch(toggleSharePreviousQueryStart(queryId));

    return api.patchStoredQuery(datasetId, queryId, { shared: shared }).then(function (r) {
      return dispatch(toggleSharePreviousQuerySuccess(queryId, shared, r));
    }, function (e) {
      return dispatch(toggleSharePreviousQueryError(queryId, {
        message: T.translate('previousQuery.shareError')
      }));
    });
  };
};

export var deletePreviousQueryStart = function deletePreviousQueryStart(queryId) {
  return { type: DELETE_PREVIOUS_QUERY_START, payload: { queryId: queryId } };
};
export var deletePreviousQuerySuccess = function deletePreviousQuerySuccess(queryId, res) {
  return defaultSuccess(DELETE_PREVIOUS_QUERY_SUCCESS, res, { queryId: queryId });
};
export var deletePreviousQueryError = function deletePreviousQueryError(queryId, err) {
  return defaultError(DELETE_PREVIOUS_QUERY_ERROR, err, { queryId: queryId });
};

export var deletePreviousQuery = function deletePreviousQuery(datasetId, queryId) {
  return function (dispatch) {
    dispatch(deletePreviousQueryStart(queryId));

    return api.deleteStoredQuery(datasetId, queryId).then(function (r) {
      return dispatch(deletePreviousQuerySuccess(queryId, r));
    }, function (e) {
      return dispatch(deletePreviousQueryError(queryId, {
        message: T.translate('previousQuery.deleteError')
      }));
    });
  };
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(loadPreviousQueriesStart, 'loadPreviousQueriesStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQueriesSuccess, 'loadPreviousQueriesSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQueriesError, 'loadPreviousQueriesError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQueries, 'loadPreviousQueries', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQueryStart, 'loadPreviousQueryStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQuerySuccess, 'loadPreviousQuerySuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQueryError, 'loadPreviousQueryError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadPreviousQuery, 'loadPreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(loadAllPreviousQueriesInGroups, 'loadAllPreviousQueriesInGroups', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(toggleEditPreviousQueryLabel, 'toggleEditPreviousQueryLabel', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(renamePreviousQueryStart, 'renamePreviousQueryStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(renamePreviousQuerySuccess, 'renamePreviousQuerySuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(renamePreviousQueryError, 'renamePreviousQueryError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(renamePreviousQuery, 'renamePreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(toggleEditPreviousQueryTags, 'toggleEditPreviousQueryTags', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(retagPreviousQueryStart, 'retagPreviousQueryStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(retagPreviousQuerySuccess, 'retagPreviousQuerySuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(retagPreviousQueryError, 'retagPreviousQueryError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(retagPreviousQuery, 'retagPreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(toggleSharePreviousQueryStart, 'toggleSharePreviousQueryStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(toggleSharePreviousQuerySuccess, 'toggleSharePreviousQuerySuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(toggleSharePreviousQueryError, 'toggleSharePreviousQueryError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(toggleSharePreviousQuery, 'toggleSharePreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(deletePreviousQueryStart, 'deletePreviousQueryStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(deletePreviousQuerySuccess, 'deletePreviousQuerySuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(deletePreviousQueryError, 'deletePreviousQueryError', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  reactHotLoader.register(deletePreviousQuery, 'deletePreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/actions.js');
  leaveModule(module);
})();

;