var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import { LOAD_PREVIOUS_QUERIES_START, LOAD_PREVIOUS_QUERIES_SUCCESS, LOAD_PREVIOUS_QUERIES_ERROR, LOAD_PREVIOUS_QUERY_START, LOAD_PREVIOUS_QUERY_SUCCESS, LOAD_PREVIOUS_QUERY_ERROR, RENAME_PREVIOUS_QUERY_START, RENAME_PREVIOUS_QUERY_SUCCESS, RENAME_PREVIOUS_QUERY_ERROR, TOGGLE_EDIT_PREVIOUS_QUERY_LABEL, TOGGLE_EDIT_PREVIOUS_QUERY_TAGS, RETAG_PREVIOUS_QUERY_START, RETAG_PREVIOUS_QUERY_SUCCESS, RETAG_PREVIOUS_QUERY_ERROR, TOGGLE_SHARE_PREVIOUS_QUERY_START, TOGGLE_SHARE_PREVIOUS_QUERY_SUCCESS, TOGGLE_SHARE_PREVIOUS_QUERY_ERROR, DELETE_PREVIOUS_QUERY_START, DELETE_PREVIOUS_QUERY_SUCCESS, DELETE_PREVIOUS_QUERY_ERROR } from './actionTypes';

var initialState = {
  queries: []
};

var findQuery = function findQuery(queries, queryId) {
  var query = queries.find(function (q) {
    return q.id === queryId;
  });

  return {
    query: query,
    queryIdx: queries.indexOf(query)
  };
};

var updatePreviousQuery = function updatePreviousQuery(state, action, attributes) {
  var _findQuery = findQuery(state.queries, action.payload.queryId),
      query = _findQuery.query,
      queryIdx = _findQuery.queryIdx;

  return _extends({}, state, {
    queries: [].concat(_toConsumableArray(state.queries.slice(0, queryIdx)), [_extends({}, query, attributes)], _toConsumableArray(state.queries.slice(queryIdx + 1)))
  });
};

var sortQueries = function sortQueries(queries) {
  return queries.sort(function (a, b) {
    return new Date(b.createdAt) - new Date(a.createdAt);
  });
};

var toggleQueryAttribute = function toggleQueryAttribute(state, action, attribute) {
  var _findQuery2 = findQuery(state.queries, action.payload.queryId),
      query = _findQuery2.query;

  return updatePreviousQuery(state, action, _defineProperty({}, attribute, !query[attribute]));
};

var deletePreviousQuery = function deletePreviousQuery(state, action) {
  var _findQuery3 = findQuery(state.queries, action.payload.queryId),
      queryIdx = _findQuery3.queryIdx;

  return _extends({}, state, {
    queries: [].concat(_toConsumableArray(state.queries.slice(0, queryIdx)), _toConsumableArray(state.queries.slice(queryIdx + 1)))
  });
};

var findUniqueTags = function findUniqueTags(queries) {
  var uniqueTags = new Set();

  queries.forEach(function (query) {
    if (query.tags) query.tags.forEach(function (tag) {
      return uniqueTags.add(tag);
    });
  });

  return Array.from(uniqueTags);
};

var findNewTags = function findNewTags(tags) {
  if (!tags) return [];

  var uniqueTags = new Set();

  tags.forEach(function (tag) {
    return uniqueTags.add(tag);
  });

  return Array.from(uniqueTags);
};

var findUniqueNames = function findUniqueNames(queries) {
  var uniqueNames = new Set();

  queries.filter(function (q) {
    return !!q.label;
  }).forEach(function (q) {
    return uniqueNames.add(q.label);
  });

  return Array.from(uniqueNames);
};

var updateUniqueNames = function updateUniqueNames(existingNames, newName) {
  return existingNames.includes(newName) ? existingNames : [newName].concat(_toConsumableArray(existingNames));
};

var previousQueriesReducer = function previousQueriesReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    case LOAD_PREVIOUS_QUERIES_START:
      return _extends({}, state, { loading: true });
    case LOAD_PREVIOUS_QUERIES_SUCCESS:
      return _extends({}, state, {
        loading: false,
        queries: sortQueries(action.payload.data),
        tags: findUniqueTags(action.payload.data),
        names: findUniqueNames(action.payload.data)
      });
    case LOAD_PREVIOUS_QUERIES_ERROR:
      return _extends({}, state, { loading: false, error: action.payload.message });
    case LOAD_PREVIOUS_QUERY_START:
    case RENAME_PREVIOUS_QUERY_START:
    case RETAG_PREVIOUS_QUERY_START:
    case TOGGLE_SHARE_PREVIOUS_QUERY_START:
    case DELETE_PREVIOUS_QUERY_START:
      return updatePreviousQuery(state, action, { loading: true });
    case LOAD_PREVIOUS_QUERY_SUCCESS:
      return updatePreviousQuery(state, action, _extends({ loading: false, error: null }, action.payload.data));
    case RENAME_PREVIOUS_QUERY_SUCCESS:
      return _extends({}, updatePreviousQuery(state, action, { loading: false, error: null, label: action.payload.label }), {
        names: updateUniqueNames(state.names, action.payload.label)
      });
    case RETAG_PREVIOUS_QUERY_SUCCESS:
      return _extends({}, updatePreviousQuery(state, action, { loading: false, error: null, tags: action.payload.tags }), {
        tags: findNewTags([].concat(_toConsumableArray(state.tags), _toConsumableArray(action.payload.tags)))
      });
    case TOGGLE_SHARE_PREVIOUS_QUERY_SUCCESS:
      return updatePreviousQuery(state, action, { loading: false, error: null, shared: action.payload.shared });
    case DELETE_PREVIOUS_QUERY_SUCCESS:
      return deletePreviousQuery(state, action);
    case LOAD_PREVIOUS_QUERY_ERROR:
    case RENAME_PREVIOUS_QUERY_ERROR:
    case RETAG_PREVIOUS_QUERY_ERROR:
    case TOGGLE_SHARE_PREVIOUS_QUERY_ERROR:
    case DELETE_PREVIOUS_QUERY_ERROR:
      return updatePreviousQuery(state, action, { loading: false, error: action.payload.message });
    case TOGGLE_EDIT_PREVIOUS_QUERY_LABEL:
      return toggleQueryAttribute(state, action, 'editingLabel');
    case TOGGLE_EDIT_PREVIOUS_QUERY_TAGS:
      return toggleQueryAttribute(state, action, 'editingTags');
    default:
      return state;
  }
};

var _default = previousQueriesReducer;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(initialState, 'initialState', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(findQuery, 'findQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(updatePreviousQuery, 'updatePreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(sortQueries, 'sortQueries', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(toggleQueryAttribute, 'toggleQueryAttribute', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(deletePreviousQuery, 'deletePreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(findUniqueTags, 'findUniqueTags', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(findNewTags, 'findNewTags', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(findUniqueNames, 'findUniqueNames', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(updateUniqueNames, 'updateUniqueNames', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(previousQueriesReducer, 'previousQueriesReducer', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/previous-queries/list/reducer.js');
  leaveModule(module);
})();

;