(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import classnames from 'classnames';
import T from 'i18n-react';
import { DropTarget } from 'react-dnd';
import { dndTypes } from '../common/constants';

import { AdditionalInfoHoverable } from '../tooltip';
import { EditableText } from '../form-components';
import { IconButton } from '../button';

import { getConceptById } from '../category-trees/globalTreeStoreHelper';

var ConceptEntry = AdditionalInfoHoverable(function (_ref) {
  var node = _ref.node,
      canRemoveConcepts = _ref.canRemoveConcepts,
      onRemoveConcept = _ref.onRemoveConcept,
      conceptId = _ref.conceptId;
  return React.createElement(
    'div',
    { className: 'query-node-editor__concept' },
    React.createElement(
      'div',
      null,
      React.createElement(
        'h6',
        null,
        node.label
      ),
      node.description && React.createElement(
        'p',
        null,
        node.description
      )
    ),
    canRemoveConcepts && React.createElement(IconButton, {
      onClick: function onClick() {
        return onRemoveConcept(conceptId);
      },
      className: 'btn--small btn--transparent',
      iconClassName: 'fa-trash-o'
    })
  );
});

var dropzoneTarget = {
  drop: function drop(props, monitor) {
    var item = monitor.getItem();
    props.onDropConcept(item);
  },
  canDrop: function canDrop(_ref2, monitor) {
    var node = _ref2.node;

    var item = monitor.getItem();
    // The dragged item should contain exactly one id
    // since it was dragged from the tree
    var conceptId = item.ids[0];
    return item.tree === node.tree && !node.ids.some(function (id) {
      return id === conceptId;
    });
  }
};

var collect = function collect(connect, monitor) {
  return {
    connectDropTarget: connect.dropTarget(),
    isOver: monitor.isOver(),
    canDrop: monitor.canDrop()
  };
};

var ConceptDropzone = DropTarget(dndTypes.CATEGORY_TREE_NODE, dropzoneTarget, collect)(function (props) {
  return props.connectDropTarget(React.createElement(
    'div',
    { className: 'query-editor-dropzone' },
    React.createElement(
      'div',
      { className: classnames('dropzone', {
          'dropzone--over': props.isOver && props.canDrop,
          'dropzone--disallowed': props.isOver && !props.canDrop
        }) },
      React.createElement(
        'p',
        { className: 'dropzone__text' },
        T.translate('queryNodeEditor.dropConcept')
      )
    )
  ));
});

export var NodeDetailsView = function NodeDetailsView(props) {
  var node = props.node,
      editorState = props.editorState;


  return React.createElement(
    'div',
    { className: 'query-node-editor__large_column query-node-editor__column' },
    React.createElement(
      'h4',
      null,
      !node.isPreviousQuery && React.createElement(EditableText, {
        loading: false,
        text: node.label,
        selectTextOnMount: true,
        editing: editorState.editingLabel,
        onSubmit: function onSubmit(value) {
          props.onUpdateLabel(value);editorState.onToggleEditLabel();
        },
        onToggleEdit: editorState.onToggleEditLabel
      }),
      node.isPreviousQuery && (node.label || node.id || node.ids)
    ),
    React.createElement(
      'div',
      { className: 'query-node-editor__column_content' },
      props.isExcludeTimestampsPossible && React.createElement(
        'div',
        { className: 'query-node-editor__row' },
        React.createElement(
          'button',
          {
            type: 'button',
            className: 'btn btn--header-transparent',
            onClick: function onClick() {
              return props.onToggleTimestamps(!node.excludeTimestamps);
            }
          },
          React.createElement('i', { className: classnames('fa', {
              'fa-square-o': !node.excludeTimestamps,
              'fa-check-square-o': node.excludeTimestamps
            }) }),
          ' ',
          T.translate('queryNodeEditor.excludeTimestamps')
        )
      ),
      !node.isPreviousQuery && React.createElement(
        'div',
        { className: 'query-node-editor__row' },
        React.createElement(
          'h5',
          null,
          [getConceptById(node.tree).label]
        ),
        React.createElement(
          'div',
          null,
          React.createElement(ConceptDropzone, { node: node, onDropConcept: props.onDropConcept })
        ),
        React.createElement(
          'div',
          null,
          node.ids.map(function (conceptId) {
            return React.createElement(ConceptEntry, {
              key: conceptId,
              node: getConceptById(conceptId),
              canRemoveConcepts: node.ids.length > 1,
              onRemoveConcept: props.onRemoveConcept,
              conceptId: conceptId
            });
          })
        )
      )
    )
  );
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(ConceptEntry, 'ConceptEntry', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/NodeDetailsView.js');
  reactHotLoader.register(dropzoneTarget, 'dropzoneTarget', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/NodeDetailsView.js');
  reactHotLoader.register(collect, 'collect', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/NodeDetailsView.js');
  reactHotLoader.register(ConceptDropzone, 'ConceptDropzone', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/NodeDetailsView.js');
  reactHotLoader.register(NodeDetailsView, 'NodeDetailsView', '/home/travis/build/bakdata/conquery/frontend/lib/js/query-node-editor/NodeDetailsView.js');
  leaveModule(module);
})();

;