var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import T from 'i18n-react';
import { DragSource } from 'react-dnd';

import { dndTypes } from '../common/constants';
import { AdditionalInfoHoverable } from '../tooltip';
import { ErrorMessage } from '../error-message';
import { nodeHasActiveFilters } from '../model/node';

import QueryNodeActions from './QueryNodeActions';

var QueryNode = function QueryNode(props) {
  var node = props.node;


  return props.connectDragSource(React.createElement(
    'div',
    { className: 'query-node' },
    React.createElement(QueryNodeActions, {
      hasActiveFilters: nodeHasActiveFilters(node),
      onFilterClick: props.onFilterClick,
      onDeleteNode: props.onDeleteNode,
      isExpandable: node.isPreviousQuery,
      onExpandClick: function onExpandClick() {
        if (!node.query) return;

        props.onExpandClick(node.query.groups, node.id);
      },
      previousQueryLoading: node.loading,
      error: node.error
    }),
    node.isPreviousQuery && React.createElement(
      'p',
      { className: 'query-node__previous-query' },
      T.translate('queryEditor.previousQuery')
    ),
    node.error ? React.createElement(ErrorMessage, {
      className: 'query-node__content',
      message: node.error
    }) : React.createElement(
      'p',
      { className: 'query-node__content' },
      React.createElement(
        'span',
        null,
        node.label || node.id
      ),
      node.description && React.createElement(
        'span',
        null,
        ' - ',
        node.description
      )
    )
  ));
};

/**
 * Implements the drag source contract.
 */
var nodeSource = {
  beginDrag: function beginDrag(props) {
    // Return the data describing the dragged item
    // NOT using `...node` since that would also spread `children` in.
    // This item may stem from either:
    // 1) A concept (dragged from CategoryTreeNode)
    // 2) A previous query (dragged from PreviousQueries)
    var node = props.node,
        andIdx = props.andIdx,
        orIdx = props.orIdx;


    var draggedNode = {
      moved: true,
      andIdx: andIdx,
      orIdx: orIdx,

      label: node.label,
      excludeTimestamps: node.excludeTimestamps,

      loading: node.loading,
      error: node.error
    };

    if (node.isPreviousQuery) return _extends({}, draggedNode, {
      id: node.id,
      query: node.query,
      isPreviousQuery: true
    });else return _extends({}, draggedNode, {
      ids: node.ids,
      tree: node.tree,
      tables: node.tables
    });
  }
};

/**
 * Specifies the dnd-related props to inject into the component.
 */
var collect = function collect(connect, monitor) {
  return {
    connectDragSource: connect.dragSource(),
    isDragging: monitor.isDragging()
  };
};

var DraggableQueryNode = DragSource(dndTypes.QUERY_NODE, nodeSource, collect)(QueryNode);

var _default = AdditionalInfoHoverable(DraggableQueryNode);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(QueryNode, 'QueryNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/QueryNode.js');
  reactHotLoader.register(nodeSource, 'nodeSource', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/QueryNode.js');
  reactHotLoader.register(collect, 'collect', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/QueryNode.js');
  reactHotLoader.register(DraggableQueryNode, 'DraggableQueryNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/QueryNode.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/QueryNode.js');
  leaveModule(module);
})();

;