var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import 'redux-thunk';

import api from '../api';
import '../common/types/backend';
import { dropFiles } from '../file-upload/actions';
import { conceptFilterValuesResolve } from '../upload-concept-list-modal/actions';

import { DROP_AND_NODE, DROP_OR_NODE, DELETE_NODE, DELETE_GROUP, TOGGLE_EXCLUDE_GROUP, LOAD_QUERY, CLEAR_QUERY, EXPAND_PREVIOUS_QUERY, SELECT_NODE_FOR_EDITING, DESELECT_NODE, UPDATE_NODE_LABEL, ADD_CONCEPT_TO_NODE, REMOVE_CONCEPT_FROM_NODE, TOGGLE_TABLE, SET_FILTER_VALUE, RESET_ALL_FILTERS, SWITCH_FILTER_MODE, TOGGLE_TIMESTAMPS, LOAD_FILTER_SUGGESTIONS_START, LOAD_FILTER_SUGGESTIONS_SUCCESS, LOAD_FILTER_SUGGESTIONS_ERROR, SET_RESOLVED_FILTER_VALUES, TOGGLE_INCLUDE_SUBNODES } from './actionTypes';

export var dropAndNode = function dropAndNode(item, dateRange) {
  return {
    type: DROP_AND_NODE,
    payload: { item: item, dateRange: dateRange }
  };
};

export var dropOrNode = function dropOrNode(item, andIdx) {
  return {
    type: DROP_OR_NODE,
    payload: { item: item, andIdx: andIdx }
  };
};

export var deleteNode = function deleteNode(andIdx, orIdx) {
  return {
    type: DELETE_NODE,
    payload: { andIdx: andIdx, orIdx: orIdx }
  };
};

export var deleteGroup = function deleteGroup(andIdx, orIdx) {
  return {
    type: DELETE_GROUP,
    payload: { andIdx: andIdx, orIdx: orIdx }
  };
};

export var toggleExcludeGroup = function toggleExcludeGroup(andIdx) {
  return {
    type: TOGGLE_EXCLUDE_GROUP,
    payload: { andIdx: andIdx }
  };
};

export var loadQuery = function loadQuery(query) {
  return {
    type: LOAD_QUERY,
    payload: { query: query }
  };
};

export var clearQuery = function clearQuery() {
  return { type: CLEAR_QUERY };
};

export var expandPreviousQuery = function expandPreviousQuery(rootConcepts, groups) {
  return {
    type: EXPAND_PREVIOUS_QUERY,
    payload: { rootConcepts: rootConcepts, groups: groups }
  };
};

export var selectNodeForEditing = function selectNodeForEditing(andIdx, orIdx) {
  return {
    type: SELECT_NODE_FOR_EDITING,
    payload: { andIdx: andIdx, orIdx: orIdx }
  };
};

export var deselectNode = function deselectNode() {
  return { type: DESELECT_NODE };
};

export var updateNodeLabel = function updateNodeLabel(label) {
  return { type: UPDATE_NODE_LABEL, label: label };
};
export var addConceptToNode = function addConceptToNode(concept) {
  return { type: ADD_CONCEPT_TO_NODE, concept: concept };
};
export var removeConceptFromNode = function removeConceptFromNode(conceptId) {
  return { type: REMOVE_CONCEPT_FROM_NODE, conceptId: conceptId };
};

export var toggleTable = function toggleTable(tableIdx, isExcluded) {
  return {
    type: TOGGLE_TABLE,
    payload: { tableIdx: tableIdx, isExcluded: isExcluded }
  };
};

export var setFilterValue = function setFilterValue(tableIdx, filterIdx, value, formattedValue) {
  return {
    type: SET_FILTER_VALUE,
    payload: { tableIdx: tableIdx, filterIdx: filterIdx, value: value, formattedValue: formattedValue }
  };
};

export var resetAllFilters = function resetAllFilters(andIdx, orIdx) {
  return {
    type: RESET_ALL_FILTERS,
    payload: { andIdx: andIdx, orIdx: orIdx }
  };
};

export var switchFilterMode = function switchFilterMode(tableIdx, filterIdx, mode) {
  return {
    type: SWITCH_FILTER_MODE,
    payload: { tableIdx: tableIdx, filterIdx: filterIdx, mode: mode }
  };
};

export var toggleTimestamps = function toggleTimestamps(isExcluded) {
  return {
    type: TOGGLE_TIMESTAMPS,
    payload: { isExcluded: isExcluded }
  };
};

export var toggleIncludeSubnodes = function toggleIncludeSubnodes(includeSubnodes) {
  return {
    type: TOGGLE_INCLUDE_SUBNODES,
    payload: { includeSubnodes: includeSubnodes }
  };
};

export var loadFilterSuggestionsStart = function loadFilterSuggestionsStart(tableIdx, conceptId, filterIdx, prefix) {
  return {
    type: LOAD_FILTER_SUGGESTIONS_START,
    payload: { tableIdx: tableIdx, conceptId: conceptId, filterIdx: filterIdx, prefix: prefix }
  };
};

export var loadFilterSuggestionsSuccess = function loadFilterSuggestionsSuccess(suggestions, tableIdx, filterIdx) {
  return {
    type: LOAD_FILTER_SUGGESTIONS_SUCCESS,
    payload: {
      suggestions: suggestions,
      tableIdx: tableIdx,
      filterIdx: filterIdx
    }
  };
};

export var loadFilterSuggestionsError = function loadFilterSuggestionsError(error, tableIdx, filterIdx) {
  return {
    type: LOAD_FILTER_SUGGESTIONS_ERROR,
    payload: _extends({
      message: error.message
    }, error, {
      tableIdx: tableIdx,
      filterIdx: filterIdx
    })
  };
};

export var loadFilterSuggestions = function loadFilterSuggestions(datasetId, tableIdx, tableId, conceptId, filterIdx, filterId, prefix) {
  return function (dispatch) {
    dispatch(loadFilterSuggestionsStart(tableIdx, conceptId, filterIdx, prefix));

    return api.postPrefixForSuggestions(datasetId, conceptId, tableId, filterId, prefix).then(function (r) {
      return dispatch(loadFilterSuggestionsSuccess(r, tableIdx, filterIdx));
    }, function (e) {
      return dispatch(loadFilterSuggestionsError(e, tableIdx, filterIdx));
    });
  };
};

export var onDropFiles = function onDropFiles(datasetId, treeId, tableIdx, tableId, filterIdx, filterId, files) {
  return dropFiles(files, {
    parameters: {
      actionType: SET_RESOLVED_FILTER_VALUES,
      datasetId: datasetId,
      treeId: treeId,
      tableIdx: tableIdx,
      tableId: tableId,
      filterIdx: filterIdx,
      filterId: filterId
    },
    callback: conceptFilterValuesResolve
  });
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(dropAndNode, 'dropAndNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(dropOrNode, 'dropOrNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(deleteNode, 'deleteNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(deleteGroup, 'deleteGroup', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(toggleExcludeGroup, 'toggleExcludeGroup', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(loadQuery, 'loadQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(clearQuery, 'clearQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(expandPreviousQuery, 'expandPreviousQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(selectNodeForEditing, 'selectNodeForEditing', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(deselectNode, 'deselectNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(updateNodeLabel, 'updateNodeLabel', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(addConceptToNode, 'addConceptToNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(removeConceptFromNode, 'removeConceptFromNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(toggleTable, 'toggleTable', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(setFilterValue, 'setFilterValue', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(resetAllFilters, 'resetAllFilters', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(switchFilterMode, 'switchFilterMode', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(toggleTimestamps, 'toggleTimestamps', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(toggleIncludeSubnodes, 'toggleIncludeSubnodes', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(loadFilterSuggestionsStart, 'loadFilterSuggestionsStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(loadFilterSuggestionsSuccess, 'loadFilterSuggestionsSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(loadFilterSuggestionsError, 'loadFilterSuggestionsError', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(loadFilterSuggestions, 'loadFilterSuggestions', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  reactHotLoader.register(onDropFiles, 'onDropFiles', '/home/travis/build/bakdata/conquery/frontend/lib/js/standard-query-editor/actions.js');
  leaveModule(module);
})();

;