(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import T from 'i18n-react';

import { BEFORE, BEFORE_OR_SAME, DAYS_BEFORE, SAME, DAYS_OR_NO_EVENT_BEFORE } from '../common/constants/timebasedQueryOperatorTypes';
import { isEmpty } from '../common/helpers';

import { VerticalToggleButton } from '../form-components';

import TimebasedQueryEditorDropzone from './TimebasedQueryEditorDropzone';
import TimebasedConditionDayRange from './TimebasedConditionDayRange';
import TimebasedNode from './TimebasedNode';

var TimebasedCondition = function TimebasedCondition(props) {
  var minDays = !isEmpty(props.condition.minDays) ? props.condition.minDays : '';
  var maxDays = !isEmpty(props.condition.maxDays) ? props.condition.maxDays : '';
  var minDaysOrNoEvent = !isEmpty(props.condition.minDaysOrNoEvent) ? props.condition.minDaysOrNoEvent : '';

  var createTimebasedResult = function createTimebasedResult(idx) {
    return props.condition['result' + idx] ? React.createElement(TimebasedNode, {
      node: props.condition['result' + idx],
      conditionIdx: props.conditionIdx,
      resultIdx: idx,
      isIndexResult: props.condition['result' + idx].id === props.indexResult,
      position: idx === 0 ? "left" : "right",
      onRemove: function onRemove() {
        return props.onRemoveTimebasedNode(idx, false);
      },
      onSetTimebasedNodeTimestamp: function onSetTimebasedNodeTimestamp(timestamp) {
        props.onSetTimebasedNodeTimestamp(idx, timestamp);
      },
      onSetTimebasedIndexResult: function onSetTimebasedIndexResult() {
        props.onSetTimebasedIndexResult(props.condition['result' + idx].id);
      },
      isIndexResultDisabled: idx === 0 && props.condition.operator === DAYS_OR_NO_EVENT_BEFORE
    }) : React.createElement(TimebasedQueryEditorDropzone, {
      onDropNode: function onDropNode(node, moved) {
        return props.onDropTimebasedNode(idx, node, moved);
      }
    });
  };

  var result0 = createTimebasedResult(0);
  var result1 = createTimebasedResult(1);

  return React.createElement(
    'div',
    { className: 'timebased-condition' },
    React.createElement('div', { className: 'timebased-condition__background' }),
    props.removable && React.createElement(
      'span',
      {
        onClick: props.onRemove,
        className: 'timebased-condition__remove-btn btn btn--icon'
      },
      React.createElement('i', { className: 'fa fa-close' })
    ),
    React.createElement(
      'div',
      { className: 'timebased-condition__nodes-container' },
      React.createElement('div', { className: 'timebased-condition__horizontal-line' }),
      React.createElement(
        'div',
        { className: 'timebased-condition__nodes' },
        result0,
        React.createElement(
          'div',
          { className: 'timebased-condition__operator' },
          React.createElement(VerticalToggleButton, {
            onToggle: props.onSetOperator,
            activeValue: props.condition.operator,
            options: [{
              label: T.translate('timebasedQueryEditor.opBefore'),
              value: BEFORE
            }, {
              label: T.translate('timebasedQueryEditor.opBeforeOrSame'),
              value: BEFORE_OR_SAME
            }, {
              label: T.translate('timebasedQueryEditor.opDays'),
              value: DAYS_BEFORE
            }, {
              label: T.translate('timebasedQueryEditor.opSame'),
              value: SAME
            }, {
              label: T.translate('timebasedQueryEditor.opDaysOrNoEventBefore'),
              value: DAYS_OR_NO_EVENT_BEFORE
            }]
          })
        ),
        result1
      )
    ),
    props.condition.operator === DAYS_BEFORE && React.createElement(TimebasedConditionDayRange, {
      minDays: minDays,
      maxDays: maxDays,
      onSetTimebasedConditionMinDays: props.onSetTimebasedConditionMinDays,
      onSetTimebasedConditionMaxDays: props.onSetTimebasedConditionMaxDays
    }),
    props.condition.operator === DAYS_OR_NO_EVENT_BEFORE && React.createElement(TimebasedConditionDayRange, {
      minDays: minDaysOrNoEvent,
      onSetTimebasedConditionMinDays: props.onSetTimebasedConditionMinDaysOrNoEvent
    })
  );
};

var _default = TimebasedCondition;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(TimebasedCondition, 'TimebasedCondition', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedCondition.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedCondition.js');
  leaveModule(module);
})();

;