(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import T from 'i18n-react';

import { addTimebasedCondition, removeTimebasedCondition, setTimebasedConditionOperator, dropTimebasedNode, setTimebasedNodeTimestamp, removeTimebasedNode, setTimebasedIndexResult, setTimebasedConditionMinDays, setTimebasedConditionMaxDays, setTimebasedConditionMinDaysOrNoEvent, setTimebasedConditionMaxDaysOrNoEvent } from './actions';

import TimebasedCondition from './TimebasedCondition';

var TimebasedQueryEditor = function TimebasedQueryEditor(props) {
  return React.createElement(
    'div',
    { className: 'timebased-query-editor' },
    props.query.conditions.map(function (condition, idx) {
      return [React.createElement(TimebasedCondition, {
        key: idx,
        condition: condition,
        conditionIdx: idx,
        indexResult: props.query.indexResult,
        removable: props.query.conditions.length > 1,
        onRemove: function onRemove() {
          return props.onRemoveTimebasedCondition(idx);
        },
        onRemoveTimebasedNode: function onRemoveTimebasedNode(resultIdx, moved) {
          props.onRemoveTimebasedNode(idx, resultIdx, moved);
        },
        onSetOperator: function onSetOperator(value) {
          return props.onSetTimebasedConditionOperator(idx, value);
        },
        onDropTimebasedNode: function onDropTimebasedNode(resultIdx, node, moved) {
          props.onDropTimebasedNode(idx, resultIdx, node, moved);
        },
        onSetTimebasedNodeTimestamp: function onSetTimebasedNodeTimestamp(resultIdx, timestamp) {
          props.onSetTimebasedNodeTimestamp(idx, resultIdx, timestamp);
        },
        onSetTimebasedIndexResult: props.onSetTimebasedIndexResult,
        onSetTimebasedConditionMinDays: function onSetTimebasedConditionMinDays(days) {
          props.onSetTimebasedConditionMinDays(idx, days);
        },
        onSetTimebasedConditionMaxDays: function onSetTimebasedConditionMaxDays(days) {
          props.onSetTimebasedConditionMaxDays(idx, days);
        },
        onSetTimebasedConditionMinDaysOrNoEvent: function onSetTimebasedConditionMinDaysOrNoEvent(days) {
          props.onSetTimebasedConditionMinDaysOrNoEvent(idx, days);
        },
        onSetTimebasedConditionMaxDaysOrNoEvent: function onSetTimebasedConditionMaxDaysOrNoEvent(days) {
          props.onSetTimebasedConditionMaxDaysOrNoEvent(idx, days);
        }
      }), React.createElement(
        'p',
        { className: 'timebased-query-editor__connector' },
        T.translate('common.and')
      )];
    }),
    React.createElement(
      'button',
      {
        onClick: props.onAddTimebasedCondition,
        className: 'timebased-query-editor__add-btn btn btn--transparent btn--icon'
      },
      React.createElement('i', { className: 'fa fa-plus' }),
      ' ',
      T.translate('timebasedQueryEditor.addCondition')
    )
  );
};

TimebasedQueryEditor.propTypes = {
  query: PropTypes.object.isRequired,
  onDropTimebasedNode: PropTypes.func.isRequired,
  onRemoveTimebasedNode: PropTypes.func.isRequired,
  onAddTimebasedCondition: PropTypes.func.isRequired,
  onRemoveTimebasedCondition: PropTypes.func.isRequired,
  onSetTimebasedConditionOperator: PropTypes.func.isRequired,
  onSetTimebasedNodeTimestamp: PropTypes.func.isRequired,
  onSetTimebasedIndexResult: PropTypes.func.isRequired,
  onSetTimebasedConditionMinDays: PropTypes.func.isRequired,
  onSetTimebasedConditionMaxDays: PropTypes.func.isRequired,
  onSetTimebasedConditionMinDaysOrNoEvent: PropTypes.func.isRequired,
  onSetTimebasedConditionMaxDaysOrNoEvent: PropTypes.func.isRequired
};

var mapStateToProps = function mapStateToProps(state) {
  return {
    query: state.panes.right.tabs.timebasedQueryEditor.timebasedQuery
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    onAddTimebasedCondition: function onAddTimebasedCondition() {
      return dispatch(addTimebasedCondition());
    },
    onRemoveTimebasedCondition: function onRemoveTimebasedCondition(idx) {
      return dispatch(removeTimebasedCondition(idx));
    },
    onSetTimebasedConditionOperator: function onSetTimebasedConditionOperator(idx, value) {
      return dispatch(setTimebasedConditionOperator(idx, value));
    },
    onDropTimebasedNode: function onDropTimebasedNode(conditionIdx, resultIdx, node, moved) {
      return dispatch(dropTimebasedNode(conditionIdx, resultIdx, node, moved));
    },
    onSetTimebasedNodeTimestamp: function onSetTimebasedNodeTimestamp(conditionIdx, resultIdx, timestamp) {
      return dispatch(setTimebasedNodeTimestamp(conditionIdx, resultIdx, timestamp));
    },
    onRemoveTimebasedNode: function onRemoveTimebasedNode(conditionIdx, resultIdx, moved) {
      return dispatch(removeTimebasedNode(conditionIdx, resultIdx, moved));
    },
    onSetTimebasedIndexResult: function onSetTimebasedIndexResult(indexResult) {
      return dispatch(setTimebasedIndexResult(indexResult));
    },
    onSetTimebasedConditionMinDays: function onSetTimebasedConditionMinDays(conditionIdx, days) {
      return dispatch(setTimebasedConditionMinDays(conditionIdx, days));
    },
    onSetTimebasedConditionMaxDays: function onSetTimebasedConditionMaxDays(conditionIdx, days) {
      return dispatch(setTimebasedConditionMaxDays(conditionIdx, days));
    },
    onSetTimebasedConditionMinDaysOrNoEvent: function onSetTimebasedConditionMinDaysOrNoEvent(conditionIdx, days) {
      return dispatch(setTimebasedConditionMinDaysOrNoEvent(conditionIdx, days));
    },
    onSetTimebasedConditionMaxDaysOrNoEvent: function onSetTimebasedConditionMaxDaysOrNoEvent(conditionIdx, days) {
      return dispatch(setTimebasedConditionMaxDaysOrNoEvent(conditionIdx, days));
    }
  };
};

var _default = connect(mapStateToProps, mapDispatchToProps)(TimebasedQueryEditor);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(TimebasedQueryEditor, 'TimebasedQueryEditor', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedQueryEditor.js');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedQueryEditor.js');
  reactHotLoader.register(mapDispatchToProps, 'mapDispatchToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedQueryEditor.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/TimebasedQueryEditor.js');
  leaveModule(module);
})();

;