var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import { RENAME_PREVIOUS_QUERY_SUCCESS } from '../previous-queries/list/actionTypes';

import { BEFORE, DAYS_OR_NO_EVENT_BEFORE, TIMEBASED_OPERATOR_TYPES } from '../common/constants/timebasedQueryOperatorTypes';

import { FIRST, TIMEBASED_TIMESTAMP_TYPES } from '../common/constants/timebasedQueryTimestampTypes';

import { DROP_TIMEBASED_NODE, REMOVE_TIMEBASED_NODE, SET_TIMEBASED_NODE_TIMESTAMP, SET_TIMEBASED_CONDITION_OPERATOR, SET_TIMEBASED_CONDITION_MIN_DAYS, SET_TIMEBASED_CONDITION_MAX_DAYS, SET_TIMEBASED_CONDITION_MIN_DAYS_OR_NO_EVENT, SET_TIMEBASED_CONDITION_MAX_DAYS_OR_NO_EVENT, SET_TIMEBASED_INDEX_RESULT, ADD_TIMEBASED_CONDITION, REMOVE_TIMEBASED_CONDITION, CLEAR_TIMEBASED_QUERY } from './actionTypes';

var getEmptyNode = function getEmptyNode() {
  return {
    operator: BEFORE,
    result0: null,
    result1: null
  };
};

var setTimebasedConditionAttributes = function setTimebasedConditionAttributes(state, action, attributes) {
  var conditionIdx = action.payload.conditionIdx;


  return _extends({}, state, {
    conditions: [].concat(_toConsumableArray(state.conditions.slice(0, conditionIdx)), [_extends({}, state.conditions[conditionIdx], attributes)], _toConsumableArray(state.conditions.slice(conditionIdx + 1)))
  });
};

var setNode = function setNode(state, action, node) {
  var resultIdx = action.payload.resultIdx;


  var attributes = _defineProperty({}, 'result' + resultIdx, _extends({}, node, {
    timestamp: node.timestamp || FIRST
  }));

  return setTimebasedConditionAttributes(state, action, attributes);
};

var conditionResultsToArray = function conditionResultsToArray(conditions) {
  return conditions.reduce(function (results, c) {
    if (c.result0) results.push(c.result0);
    if (c.result1) results.push(c.result1);

    return results;
  }, []);
};

var getPossibleIndexResults = function getPossibleIndexResults(conditions) {
  return conditions.reduce(function (possibleResults, condition, i) {
    if (condition.operator === DAYS_OR_NO_EVENT_BEFORE && condition.result1) possibleResults.push(condition.result1);

    if (condition.operator !== DAYS_OR_NO_EVENT_BEFORE && condition.result0) possibleResults.push(condition.result0);

    if (condition.operator !== DAYS_OR_NO_EVENT_BEFORE && condition.result1) possibleResults.push(condition.result1);

    return possibleResults;
  }, []);
};

var ensureIndexResult = function ensureIndexResult(state) {
  // Return if there is already an indexResult
  if (state.indexResult) return state;

  // Ok, so there is none, let's ensure it
  var possibleResults = getPossibleIndexResults(state.conditions);
  // allResults includes results on the left side
  // of conditions with a DAYS_OR_NO_EVENT_BEFORE operator
  var allResults = conditionResultsToArray(state.conditions);

  // Best case
  if (possibleResults.length > 0) return _extends({}, state, { indexResult: possibleResults[0].id });

  // Bad but ok case
  if (allResults.length > 0) return _extends({}, state, { indexResult: allResults[0].id });

  // Well, couldn't find any result
  return _extends({}, state, { indexResult: null });
};

var dropTimebasedNode = function dropTimebasedNode(state, action) {
  var node = action.payload.node;

  var stateWithNode = setNode(state, action, node);

  return node.moved ? stateWithNode : ensureIndexResult(stateWithNode);
};

var removeTimebasedNode = function removeTimebasedNode(state, action) {
  var _action$payload = action.payload,
      conditionIdx = _action$payload.conditionIdx,
      resultIdx = _action$payload.resultIdx,
      moved = _action$payload.moved;

  var node = state.conditions[conditionIdx]['result' + resultIdx];

  var attributes = _defineProperty({}, 'result' + resultIdx, null);

  var stateWithoutNode = setTimebasedConditionAttributes(state, action, attributes);

  if (moved) return stateWithoutNode;

  // If item has not been moved and was indexResult, remove indexResult
  var nextState = node.id === state.indexResult ? _extends({}, stateWithoutNode, { indexResult: null }) : stateWithoutNode;

  return ensureIndexResult(nextState);
};

var setTimebasedNodeTimestamp = function setTimebasedNodeTimestamp(state, action) {
  var _action$payload2 = action.payload,
      conditionIdx = _action$payload2.conditionIdx,
      resultIdx = _action$payload2.resultIdx,
      timestamp = _action$payload2.timestamp;


  var attributes = _defineProperty({}, 'result' + resultIdx, _extends({}, state.conditions[conditionIdx]['result' + resultIdx], {
    timestamp: timestamp
  }));

  return setTimebasedConditionAttributes(state, action, attributes);
};

var setTimebasedConditionOperator = function setTimebasedConditionOperator(state, action) {
  var _action$payload3 = action.payload,
      conditionIdx = _action$payload3.conditionIdx,
      operator = _action$payload3.operator;

  // Check if we're not switching to DAYS_OR_NO_EVENT_BEFORE. Then we're good.
  // But IF IN FACT we do, check if the indexResult is somewhere else than on the left result
  // Then we're also good.

  var nextState = setTimebasedConditionAttributes(state, action, { operator: operator });

  if (operator !== DAYS_OR_NO_EVENT_BEFORE || !state.conditions[conditionIdx].result0 || state.conditions[conditionIdx].result0.id !== state.indexResult) return nextState;

  // Now that this didn't work we're switching the operator to DAYS_OR_NO_EVENT_BEFORE
  // and the indexResult points to the first of both results of this condition.
  // This is not allowed with DAYS_OR_NO_EVENT_BEFORE.

  // Let's try to find a possible result to be the new indexResult
  var possibleResults = getPossibleIndexResults(nextState.conditions);

  // Now let's hope we found a possible result
  return possibleResults.length === 0
  // Too bad, couldn't find a possible result
  ? nextState
  // Nice, take the first result
  : _extends({}, nextState, {
    indexResult: possibleResults[0].id
  });
};

var setTimebasedConditionMinDays = function setTimebasedConditionMinDays(state, action) {
  var days = action.payload.days;


  return setTimebasedConditionAttributes(state, action, { minDays: days });
};

var setTimebasedConditionMaxDays = function setTimebasedConditionMaxDays(state, action) {
  var days = action.payload.days;


  return setTimebasedConditionAttributes(state, action, { maxDays: days });
};

var setTimebasedConditionMinDaysOrNoEvent = function setTimebasedConditionMinDaysOrNoEvent(state, action) {
  var days = action.payload.days;


  return setTimebasedConditionAttributes(state, action, { minDaysOrNoEvent: days });
};

var setTimebasedConditionMaxDaysOrNoEvent = function setTimebasedConditionMaxDaysOrNoEvent(state, action) {
  var days = action.payload.days;


  return setTimebasedConditionAttributes(state, action, { maxDaysOrNoEvent: days });
};

var setTimebasedIndexResult = function setTimebasedIndexResult(state, action) {
  var indexResult = action.payload.indexResult;


  return _extends({}, state, {
    indexResult: indexResult
  });
};

var addTimebasedCondition = function addTimebasedCondition(state, action) {
  return _extends({}, state, {
    conditions: [].concat(_toConsumableArray(state.conditions), [getEmptyNode()])
  });
};

var removeTimebasedCondition = function removeTimebasedCondition(state, action) {
  var conditionIdx = action.payload.conditionIdx;

  var deletedCondition = state.conditions[conditionIdx];
  var nextState = _extends({}, state, {
    conditions: [].concat(_toConsumableArray(state.conditions.slice(0, conditionIdx)), _toConsumableArray(state.conditions.slice(conditionIdx + 1)))
  });

  // if no node was indexed
  if (!(deletedCondition.result0 && deletedCondition.result0.id === state.indexResult) && !(deletedCondition.result1 && deletedCondition.result1.id === state.indexResult)) return nextState;

  return ensureIndexResult(_extends({}, nextState, { indexResult: null }));
};

var renamePreviousQueries = function renamePreviousQueries(state, action) {
  return _extends({}, state, {
    conditions: state.conditions.map(function (c) {
      var result0 = c.result0 && c.result0.id === action.payload.queryId ? _extends({}, c.result0, { label: action.payload.label }) : c.result0;

      var result1 = c.result1 && c.result1.id === action.payload.queryId ? _extends({}, c.result1, { label: action.payload.label }) : c.result1;

      return _extends({}, c, {
        result0: result0,
        result1: result1
      });
    })
  });
};

var initialState = {
  indexResult: null,
  conditions: [getEmptyNode()]
};

// This state contains an array of and-conditions.
// Every and-condition sets exactly two previous queries in a time-based relation.
// To be more specific, the RESULTS of two previous queries are set in relation.
// (The relation is measured in days)
//
// The result of this timebased query will look like those from any other query:
//
// A number of results with
//   id,
//   first date of occurrence,
//   last date of occurrence,
//   random dateof occurrence
//
// These dates will have to be taken from a single previous query
// (result1 or result2 from within specific condition) the "indexResult".
//
//
// Example:
//
// {
//   indexResult: 2523,
//   conditions: [
//     {
//       operator: 'BEFORE',
//       // operator: 'BEFORE_OR_SAME',
//       // operator: 'SAME',
//       result0: {
//         id: 2523,
//         timestamp: 'FIRST',
//         // timestamp: 'LAST',
//         // timestamp: 'RANDOM',
//       },
//       result1: {
//         id: 2525,
//         timestamp: 'LAST'
//       },
//       minDays: 5,
//       maxDays: 10
//     },
//     {
//       operator: 'SAME',
//       result0: { id: 6274, timestamp: "RANDOM" },
//       result1: { id: 5274, timestamp: "RANDOM" },
//     }
//   ]
// }
var timebasedQuery = function timebasedQuery() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    case DROP_TIMEBASED_NODE:
      return dropTimebasedNode(state, action);
    case REMOVE_TIMEBASED_NODE:
      return removeTimebasedNode(state, action);
    case SET_TIMEBASED_NODE_TIMESTAMP:
      return setTimebasedNodeTimestamp(state, action);
    case SET_TIMEBASED_CONDITION_OPERATOR:
      return setTimebasedConditionOperator(state, action);
    case SET_TIMEBASED_CONDITION_MIN_DAYS:
      return setTimebasedConditionMinDays(state, action);
    case SET_TIMEBASED_CONDITION_MAX_DAYS:
      return setTimebasedConditionMaxDays(state, action);
    case SET_TIMEBASED_CONDITION_MIN_DAYS_OR_NO_EVENT:
      return setTimebasedConditionMinDaysOrNoEvent(state, action);
    case SET_TIMEBASED_CONDITION_MAX_DAYS_OR_NO_EVENT:
      return setTimebasedConditionMaxDaysOrNoEvent(state, action);
    case SET_TIMEBASED_INDEX_RESULT:
      return setTimebasedIndexResult(state, action);
    case ADD_TIMEBASED_CONDITION:
      return addTimebasedCondition(state, action);
    case REMOVE_TIMEBASED_CONDITION:
      return removeTimebasedCondition(state, action);
    case RENAME_PREVIOUS_QUERY_SUCCESS:
      return renamePreviousQueries(state, action);
    case CLEAR_TIMEBASED_QUERY:
      return initialState;
    default:
      return state;
  }
};

var _default = timebasedQuery;
export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(getEmptyNode, 'getEmptyNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedConditionAttributes, 'setTimebasedConditionAttributes', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setNode, 'setNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(conditionResultsToArray, 'conditionResultsToArray', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(getPossibleIndexResults, 'getPossibleIndexResults', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(ensureIndexResult, 'ensureIndexResult', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(dropTimebasedNode, 'dropTimebasedNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(removeTimebasedNode, 'removeTimebasedNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedNodeTimestamp, 'setTimebasedNodeTimestamp', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedConditionOperator, 'setTimebasedConditionOperator', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedConditionMinDays, 'setTimebasedConditionMinDays', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedConditionMaxDays, 'setTimebasedConditionMaxDays', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedConditionMinDaysOrNoEvent, 'setTimebasedConditionMinDaysOrNoEvent', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedConditionMaxDaysOrNoEvent, 'setTimebasedConditionMaxDaysOrNoEvent', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(setTimebasedIndexResult, 'setTimebasedIndexResult', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(addTimebasedCondition, 'addTimebasedCondition', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(removeTimebasedCondition, 'removeTimebasedCondition', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(renamePreviousQueries, 'renamePreviousQueries', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(initialState, 'initialState', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(timebasedQuery, 'timebasedQuery', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/timebased-query-editor/reducer.js');
  leaveModule(module);
})();

;