var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import React from 'react';

import { connect } from 'react-redux';
import T from 'i18n-react';
import classnames from 'classnames';

import { Modal } from '../modal';
import { InputSelect, InputWithLabel } from '../form-components';
import { ScrollableList } from '../scrollable-list';


import { uploadConceptListModalUpdateLabel, selectConceptRootNodeAndResolveCodes, uploadConceptListModalClose, acceptAndCloseUploadConceptListModal } from './actions';

var UploadConceptListModal = function UploadConceptListModal(props) {
  var isModalOpen = props.isModalOpen,
      showDetails = props.showDetails,
      availableConceptRootNodes = props.availableConceptRootNodes,
      selectedConceptRootNode = props.selectedConceptRootNode,
      loading = props.loading,
      resolved = props.resolved,
      hasResolvedItems = props.hasResolvedItems,
      hasUnresolvedCodes = props.hasUnresolvedCodes,
      numberOfResolvedItems = props.numberOfResolvedItems,
      error = props.error,
      parameters = props.parameters;


  if (!isModalOpen && resolved && resolved.resolvedFilter) props.onAccept(props.label, { filter: resolved.resolvedFilter }, parameters);

  if (!isModalOpen) return null;

  return React.createElement(
    Modal,
    { closeModal: props.onCloseModal, doneButton: true },
    React.createElement(
      'div',
      { className: 'upload-concept-list-modal' },
      React.createElement(
        'h3',
        null,
        T.translate('uploadConceptListModal.headline')
      ),
      showDetails && React.createElement(InputWithLabel, {
        label: T.translate('uploadConceptListModal.label'),
        fullWidth: true,
        input: {
          value: props.label,
          onChange: function onChange(value) {
            return props.updateLabel(value);
          }
        }
      }),
      showDetails && React.createElement(
        'div',
        { className: 'upload-concept-list-modal__section' },
        React.createElement(
          'label',
          { className: 'input' },
          React.createElement(
            'span',
            { className: 'input-label' },
            T.translate('uploadConceptListModal.selectConceptRootNode')
          ),
          React.createElement(InputSelect, {
            input: {
              value: selectedConceptRootNode,
              onChange: function onChange(value) {
                return props.selectConceptRootNode(props.selectedDatasetId, value, props.conceptCodesFromFile, parameters);
              }
            },
            options: availableConceptRootNodes.map(function (x) {
              return { value: x.key, label: x.value.label };
            }),
            selectProps: {
              isSearchable: true
            }
          })
        )
      ),
      error && React.createElement(
        'div',
        { className: 'upload-concept-list-modal__status upload-concept-list-modal__section' },
        React.createElement(
          'p',
          { className: 'upload-concept-list-modal__error' },
          React.createElement('i', { className: 'fa fa-exclamation-circle fa-2x' })
        ),
        React.createElement(
          'p',
          null,
          T.translate('uploadConceptListModal.error')
        )
      ),
      loading && React.createElement(
        'div',
        { className: classnames('upload-concept-list-modal__status', 'upload-concept-list-modal__section', 'upload-concept-list-modal__loading')
        },
        React.createElement('i', { className: 'fa fa-spinner fa-2x' })
      ),
      resolved && React.createElement(
        'div',
        { className: 'upload-concept-list-modal__status upload-concept-list-modal__section' },
        hasResolvedItems && !hasUnresolvedCodes && React.createElement(
          'p',
          { className: 'upload-concept-list-modal__success' },
          React.createElement('i', { className: 'fa fa-check-circle fa-2x' })
        ),
        hasResolvedItems && hasUnresolvedCodes && React.createElement(
          'p',
          { className: 'upload-concept-list-modal__info' },
          React.createElement('i', { className: 'fa fa-info-circle fa-2x' })
        ),
        !hasResolvedItems && hasUnresolvedCodes && React.createElement(
          'p',
          { className: 'upload-concept-list-modal__error' },
          React.createElement('i', { className: 'fa fa-exclamation-circle fa-2x' })
        ),
        hasResolvedItems && React.createElement(
          'p',
          null,
          T.translate('uploadConceptListModal.resolvedCodes', { context: numberOfResolvedItems })
        ),
        hasUnresolvedCodes && React.createElement(
          'div',
          null,
          React.createElement(
            'p',
            null,
            T.translate('uploadConceptListModal.unknownCodes', { context: resolved.unknownCodes.length })
          ),
          React.createElement(
            'div',
            { className: 'upload-concept-list-modal__section' },
            React.createElement(ScrollableList, {
              maxVisibleItems: 3,
              fullWidth: true,
              items: resolved.unknownCodes
            })
          )
        )
      ),
      React.createElement(
        'div',
        { className: 'upload-concept-list-modal__accept' },
        React.createElement(
          'button',
          {
            type: 'button',
            className: 'btn btn--primary',
            disabled: !hasResolvedItems,
            onClick: function onClick() {
              return props.onAccept(props.label, {
                conceptList: props.resolved.resolvedConcepts,
                filter: props.resolved.resolvedFilter,
                selectedRoot: props.selectedConceptRootNode
              }, props.parameters);
            }
          },
          T.translate('uploadConceptListModal.insertNode')
        )
      )
    )
  );
};

var selectHasResolvedConcepts = function selectHasResolvedConcepts(state) {
  var resolved = state.uploadConceptListModal.resolved;


  return resolved && resolved.resolvedConcepts && resolved.resolvedConcepts.length;
};

var selectHasResolvedFilters = function selectHasResolvedFilters(state) {
  var resolved = state.uploadConceptListModal.resolved;


  return resolved && resolved.resolvedFilter && resolved.resolvedFilter.value && resolved.resolvedFilter.value.length;
};

var selectHasResolvedItems = function selectHasResolvedItems(state) {
  return selectHasResolvedConcepts(state) || selectHasResolvedFilters(state);
};

var selectHasUnresolvedCodes = function selectHasUnresolvedCodes(state) {
  var resolved = state.uploadConceptListModal.resolved;


  return resolved && resolved.unknownCodes && resolved.unknownCodes.length;
};

var selectNumberOfResolvedItems = function selectNumberOfResolvedItems(state) {
  var resolved = state.uploadConceptListModal.resolved;


  if (!selectHasResolvedItems(state)) return 0;

  if (selectHasResolvedConcepts(state)) return resolved.resolvedConcepts.length;else return resolved.resolvedFilter.value.length;
};

var selectAvailableConceptRootNodes = function selectAvailableConceptRootNodes(state) {
  var trees = state.categoryTrees.trees;


  return Object.entries(trees).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    return { key: key, value: value };
  }).filter(function (_ref3) {
    var key = _ref3.key,
        value = _ref3.value;
    return value.codeListResolvable;
  }).sort(function (a, b) {
    return a.value.label.toLowerCase().localeCompare(b.value.label.toLowerCase());
  });
};

var selectShowDetails = function selectShowDetails(state) {
  var showDetails = state.uploadConceptListModal.showDetails;


  if (typeof showDetails === 'undefined') return true;

  return showDetails;
};

var mapStateToProps = function mapStateToProps(state) {
  return {
    isModalOpen: state.uploadConceptListModal.isModalOpen,
    showDetails: selectShowDetails(state),
    parameters: state.uploadConceptListModal.parameters,
    label: state.uploadConceptListModal.label,
    conceptCodesFromFile: state.uploadConceptListModal.conceptCodesFromFile,
    availableConceptRootNodes: selectAvailableConceptRootNodes(state),
    selectedConceptRootNode: state.uploadConceptListModal.selectedConceptRootNode,
    loading: state.uploadConceptListModal.loading,
    resolved: state.uploadConceptListModal.resolved,
    hasResolvedItems: selectHasResolvedItems(state),
    hasUnresolvedCodes: selectHasUnresolvedCodes(state),
    numberOfResolvedItems: selectNumberOfResolvedItems(state),
    rootConcepts: state.categoryTrees.trees,
    error: state.uploadConceptListModal.error
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    onCloseModal: function onCloseModal() {
      return dispatch(uploadConceptListModalClose());
    },
    onAccept: function onAccept(label, rootConcepts, concepts, parameters) {
      return dispatch(acceptAndCloseUploadConceptListModal(label, rootConcepts, concepts, parameters));
    },
    selectConceptRootNode: function selectConceptRootNode(datasetId, treeId, conceptCodes, parameters) {
      return dispatch(selectConceptRootNodeAndResolveCodes(_extends({}, parameters, { datasetId: datasetId, treeId: treeId, conceptCodes: conceptCodes })));
    },
    updateLabel: function updateLabel(label) {
      return dispatch(uploadConceptListModalUpdateLabel(label));
    }
  };
};

var mergeProps = function mergeProps(stateProps, dispatchProps, ownProps) {
  return _extends({}, stateProps, dispatchProps, ownProps, {
    onAccept: function onAccept(fileName, concepts, parameters) {
      return dispatchProps.onAccept(fileName, stateProps.rootConcepts, concepts, parameters);
    }
  });
};

var _default = connect(mapStateToProps, mapDispatchToProps, mergeProps)(UploadConceptListModal);

export default _default;
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(UploadConceptListModal, 'UploadConceptListModal', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectHasResolvedConcepts, 'selectHasResolvedConcepts', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectHasResolvedFilters, 'selectHasResolvedFilters', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectHasResolvedItems, 'selectHasResolvedItems', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectHasUnresolvedCodes, 'selectHasUnresolvedCodes', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectNumberOfResolvedItems, 'selectNumberOfResolvedItems', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectAvailableConceptRootNodes, 'selectAvailableConceptRootNodes', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(selectShowDetails, 'selectShowDetails', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(mapStateToProps, 'mapStateToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(mapDispatchToProps, 'mapDispatchToProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(mergeProps, 'mergeProps', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  reactHotLoader.register(_default, 'default', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/UploadConceptListModal.js');
  leaveModule(module);
})();

;