var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

(function () {
  var enterModule = require('react-hot-loader').enterModule;

  enterModule && enterModule(module);
})();

import api from '../api';

import { defaultSuccess, defaultError } from '../common/actions';
import { isEmpty } from '../common/helpers';
import '../common/types/backend';
import '../file-upload/types';

import { UPLOAD_CONCEPT_LIST_MODAL_UPDATE_LABEL, SELECT_CONCEPT_ROOT_NODE, RESOLVE_CONCEPTS_START, RESOLVE_CONCEPTS_SUCCESS, RESOLVE_CONCEPTS_ERROR, UPLOAD_CONCEPT_LIST_MODAL_OPEN, UPLOAD_CONCEPT_LIST_MODAL_CLOSE, UPLOAD_CONCEPT_LIST_MODAL_ACCEPT, RESOLVE_FILTER_VALUES_SUCCESS, RESOLVE_FILTER_VALUES_ERROR } from './actionTypes';

export var resolveConceptsStart = function resolveConceptsStart() {
  return { type: RESOLVE_CONCEPTS_START };
};
export var resolveConceptsSuccess = function resolveConceptsSuccess(res, payload) {
  return defaultSuccess(RESOLVE_CONCEPTS_SUCCESS, res, payload);
};
export var resolveConceptsError = function resolveConceptsError(err) {
  return defaultError(RESOLVE_CONCEPTS_ERROR, err);
};

export var resolveFilterValuesSuccess = function resolveFilterValuesSuccess(res, payload) {
  return defaultSuccess(RESOLVE_FILTER_VALUES_SUCCESS, res, payload);
};
export var resolveFilterValuesError = function resolveFilterValuesError(err) {
  return defaultError(RESOLVE_FILTER_VALUES_ERROR, err);
};

export var selectConceptRootNode = function selectConceptRootNode(conceptId) {
  return { type: SELECT_CONCEPT_ROOT_NODE, conceptId: conceptId };
};

export var selectConceptRootNodeAndResolveCodes = function selectConceptRootNodeAndResolveCodes(parameters) {
  var treeId = parameters.treeId,
      datasetId = parameters.datasetId,
      conceptCodes = parameters.conceptCodes;


  return function (dispatch) {
    if (isEmpty(treeId)) return dispatch(selectConceptRootNode(''));else dispatch(selectConceptRootNode(treeId));

    dispatch(resolveConceptsStart());

    return api.postConceptsListToResolve(datasetId, treeId, conceptCodes).then(function (r) {
      return dispatch(resolveConceptsSuccess(r));
    }, function (e) {
      return dispatch(resolveConceptsError(e));
    });
  };
};

export var conceptFilterValuesResolve = function conceptFilterValuesResolve(fileType) {
  var datasetId = fileType.parameters.datasetId;
  var treeId = fileType.parameters.treeId;
  var tableId = fileType.parameters.tableId;
  var filterId = fileType.parameters.filterId;
  var values = fileType.parameters.values;

  return function (dispatch) {
    dispatch(resolveConceptsStart());

    return api.postConceptFilterValuesResolve(datasetId, treeId, tableId, filterId, values).then(function (r) {
      return dispatch(resolveFilterValuesSuccess(r, _extends({}, fileType)));
    }, function (e) {
      return dispatch(resolveFilterValuesError(e));
    });
  };
};

export var uploadConceptListModalUpdateLabel = function uploadConceptListModalUpdateLabel(label) {
  return { type: UPLOAD_CONCEPT_LIST_MODAL_UPDATE_LABEL, label: label };
};

export var uploadConceptListModalOpen = function uploadConceptListModalOpen(fileType) {
  var parameters = fileType.parameters;
  if (parameters.treeId) return fileType.callback && fileType.callback(parameters);

  return { type: UPLOAD_CONCEPT_LIST_MODAL_OPEN, parameters: parameters };
};

export var uploadConceptListModalClose = function uploadConceptListModalClose() {
  return { type: UPLOAD_CONCEPT_LIST_MODAL_CLOSE };
};

export var uploadConceptListModalAccept = function uploadConceptListModalAccept(label, rootConcepts, resolutionResult, parameters) {
  if (parameters.callback) return parameters.callback(label, rootConcepts, resolutionResult);

  return {
    type: parameters.actionType || UPLOAD_CONCEPT_LIST_MODAL_ACCEPT,
    data: { label: label, rootConcepts: rootConcepts, resolutionResult: resolutionResult, parameters: parameters }
  };
};

export var acceptAndCloseUploadConceptListModal = function acceptAndCloseUploadConceptListModal(label, rootConcepts, resolutionResult, parameters) {
  return function (dispatch) {
    dispatch([uploadConceptListModalAccept(label, rootConcepts, resolutionResult, parameters), uploadConceptListModalClose()]);
  };
};
;

(function () {
  var reactHotLoader = require('react-hot-loader').default;

  var leaveModule = require('react-hot-loader').leaveModule;

  if (!reactHotLoader) {
    return;
  }

  reactHotLoader.register(resolveConceptsStart, 'resolveConceptsStart', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(resolveConceptsSuccess, 'resolveConceptsSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(resolveConceptsError, 'resolveConceptsError', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(resolveFilterValuesSuccess, 'resolveFilterValuesSuccess', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(resolveFilterValuesError, 'resolveFilterValuesError', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(selectConceptRootNode, 'selectConceptRootNode', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(selectConceptRootNodeAndResolveCodes, 'selectConceptRootNodeAndResolveCodes', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(conceptFilterValuesResolve, 'conceptFilterValuesResolve', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(uploadConceptListModalUpdateLabel, 'uploadConceptListModalUpdateLabel', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(uploadConceptListModalOpen, 'uploadConceptListModalOpen', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(uploadConceptListModalClose, 'uploadConceptListModalClose', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(uploadConceptListModalAccept, 'uploadConceptListModalAccept', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  reactHotLoader.register(acceptAndCloseUploadConceptListModal, 'acceptAndCloseUploadConceptListModal', '/home/travis/build/bakdata/conquery/frontend/lib/js/upload-concept-list-modal/actions.js');
  leaveModule(module);
})();

;